#
# spec file for package chocolate-doom
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           chocolate-doom
Version:        3.0.1
Release:        lp151.3.3.1
Summary:        Conservative DOOM/Heretic/Hexen/Strife source port
License:        GPL-2.0-or-later
Group:          Amusements/Games/3D/Shoot
URL:            http://chocolate-doom.org/

#Git-Web:	https://github.com/fragglet/chocolate-doom
Source:         http://www.chocolate-doom.org/downloads/%version/%name-%version.tar.gz
Source2:        http://www.chocolate-doom.org/downloads/%version/%name-%version.tar.gz.asc
Source3:        %name.keyring
Patch1:         chdoom-iwaddir.diff
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  python
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(SDL2_mixer) >= 2.0.0
BuildRequires:  pkgconfig(SDL2_net) >= 2.0.0
%if 0%{?suse_version} >= 1500
# Leap 42.X does not have this
BuildRequires:  pkgconfig(libpng) >= 1.6.10
%endif
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(sdl2) >= 2.0.1
Provides:       chocolate-heretic = %version
Provides:       chocolate-hexen = %version
Provides:       chocolate-strife = %version

%description
Chocolate Doom is a Doom source port with focus on accurate
reproduction of the original DOS version of Doom and other games
based on the Doom engine. There are no new features, a lack of high
resolution rendering, and goes as far as to duplicate or recreate
bugs and crashes found in the DOS executable that were fixed before
the initial open-sourcing of the Doom engine.

%package bash-completion
Summary:        Chocolate Doom command line completion support for bash
Group:          System/Shells
BuildArch:      noarch
Supplements:    packageand(chocolate-doom:bash-completion)

%description bash-completion
Additions for bash-completion to support chocolate-doom.

%prep
%setup -Tqb0
%patch -P 1 -p1

%build
autoreconf -fi
%configure CFLAGS="%optflags -fcommon"
make %{?_smp_mflags}

%install
b="%buildroot"
%make_install iconsdir="%_datadir/icons/hicolor/64x64/apps" \
	docdir="%_docdir/%name"
mkdir -p "$b/%_bindir"
rm -f "$b/%_docdir/%name/INSTALL"
rm -f "$b/%_datadir/applications/chocolate-setup.desktop" # has wrong paths
%fdupes %buildroot/%_prefix

%post
echo "INFO: %name: The global IWAD directory is %_datadir/doom."

%files
%_bindir/chocolate-*
%_mandir/man*/*
%_datadir/appdata/
%_datadir/applications/*
%_datadir/icons/*
%_docdir/chocolate-*/

%files bash-completion
%_datadir/bash-completion/

%changelog
* Wed Jul  1 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.0.1
  * Fixed a bug where a client in a networked game can
    cause a stack-based buffer overflow on the server
    [CVE-2020-14983, boo#1173595]
* Sat Jun  6 2020 Jan Engelhardt <jengelh@inai.de>
- Set CFLAGS+=-fcommon.
* Wed Nov 14 2018 Jan Engelhardt <jengelh@inai.de>
- Update description.
* Wed Jan 10 2018 jengelh@inai.de
- Update to new upstream release 3.0.0 (2017-12-30)
  * Update to SDL2. All scaling is now done in hardware.
  * It is possible to toggle fullscreen with Alt-Enter.
  * On multimonitor setups, the game will remember the used screen.
  * A new parameter, -savedir allows users to specify a directory
    from which to load and save games.
  * The GOG install of Doom 3: BFG Edition is now detected.
  * The CD audio option for music playback has been removed; the CD
    playback API has been removed from SDL 2.0.
  * Strife's voices.wad is now correctly loaded before PWADs.
* Tue Jul  4 2017 jengelh@inai.de
- Update to new upstream release 2.3.0 (2016-12-29)
  * Pitch-shifting from early versions of Doom, Heretic, and Hexen
    is now supported.
  * Aspect ratio-corrected 1600×1200 PNGs are now written.
  * OPL emulation is more accurate.
  * DMX bugs with GUS cards are now better emulated.
  * Checksum calculations are fixed on big endian systems, allowing
    multiplayer games to be played in mixed little/big-endian
    environments.
  * The vanilla limit of 4046 lumps per WAD is now enforced.
  * Solidsegs overflow is emulated like in vanilla.
  * It is now possible to start multiplayer Chex Quest games.
  * Versions 1.666, 1.7, and 1.8 are emulated.
  * An issue was fixed where the game crashed while killing the
    Wraithverge in 64-bit builds.
- Drop chdoom-date.diff (no longer needed), drop
  chdoom-sdlsound.diff (merged upstream).
* Wed Nov 16 2016 jengelh@inai.de
- Add chdoom-sdlsound.diff to resolve build error with new
  libsamplerate
* Sat Nov  7 2015 jengelh@inai.de
- Update to new upstream release 2.2.1
  * The Hexen four level demo IWAD is now supported.
  * The Doom reload hack has been added back.
  * OPL music playback has been improved in a number of ways to
  match the behavior of Vanilla Doom's DMX library much more
  closely. OPL3 playback is also now supported.
- Drop chdoom-nonvoid.diff (included upstream),
  drop chdoom-prng.diff (PRNG impl. was switched)
* Sat Mar 28 2015 jengelh@inai.de
- Update to new upstream release 2.1
  * Chocolate Doom now supports high-quality substitute music packs
  that are used in place of the original MIDI music tracks.
  * Support for joysticks and gamepads has been significantly
  improved in this version.
  * OPL MIDI playback has been significantly improved. Multi-track
  MIDI files now play back properly.
  * The "no fog on spawn west" Vanilla bug is now correctly
  emulated.
  * Behavior of older versions of Doom back to v1.666 can now be
  emulated.
- Add chdoom-nonvoid.diff, chdoom-prng.diff to quench compiler
  warnings. Add chdoom-date.diff to kill __DATE__ instances.
* Sun May 11 2014 jengelh@inai.de
- Add python to BuildRequires - it is used for manpage generation
  (was previously implicitly included)
* Tue Dec 10 2013 jengelh@inai.de
- Update to new upstream release 2.0
  * Support for three other Doom engine-based games: Heretic, Hexen,
  and Strife.
* Thu May  2 2013 jengelh@inai.de
- Search /usr/share/doom for IWADs as well (bnc#818102)
  + Added chdoom-iwaddir.diff
- Remove unnecessary INSTALL file
* Mon Jun 11 2012 jengelh@inai.de
- Update to new upstream release 1.7.0
  * Running servers now re-resolve the address of the master server
  occasionally, to adapt to DNS address changes.
  * A workaround for SDL mouse lag is now only used on Windows
  (where it is needed)
  * UTF-8 usernames are supported, and Windows usernames with
  non-ASCII characters are now supported
  * Palette accuracy is reduced to 6 bits per channel, to more
  accurately emulate the PC VGA hardware
* Wed Jun  8 2011 jengelh@medozas.de
- Initial package (version 1.6.0) for build.opensuse.org
